@@ -39,7 +39,7 @@ fn main() -> Result<()> {
             (config.json_rpc_url, config.commitment)
         } else {
             info!(
-            "Could not find a valid Solana-CLI config file. Defaulting to https://psytrbhymqlkfrhudd.dev.genesysgo.net:8899/ devenet node."
+            "Could not find a valid Solana-CLI config file. Defaulting to https://psytrbhymqlkfrhudd.dev.genesysgo.net:8899/ devnet node."
         );
             (
                 String::from("https://psytrbhymqlkfrhudd.dev.genesysgo.net:8899/"),
@@ -55,6 +55,9 @@ fn main() -> Result<()> {
         Please use a private RPC endpoint for best performance results."
         );
         *USE_RATE_LIMIT.write().unwrap() = true;
+    } else if RATE_LIMIT_DELAYS.contains_key(&rpc.as_str()) {
+        *USE_RATE_LIMIT.write().unwrap() = true;
+        *RPC_DELAY_NS.write().unwrap() = RATE_LIMIT_DELAYS[&rpc.as_str()];
     }
 
     let commitment = CommitmentConfig::from_str(&commitment)?;
@@ -62,6 +65,9 @@ fn main() -> Result<()> {
 
     let client = RpcClient::new_with_timeout_and_commitment(rpc.clone(), timeout, commitment);
     match options.cmd {
+        Command::Collections {
+            collections_subcommands,
+        } => process_collections(&client, collections_subcommands)?,
         Command::Burn { burn_subcommands } => process_burn(&client, burn_subcommands)?,
         Command::Decode { decode_subcommands } => process_decode(&client, decode_subcommands)?,
         Command::Derive { derive_subcommands } => process_derive(derive_subcommands),
