@@ -2,6 +2,7 @@ use anyhow::Result;
 use solana_client::rpc_client::RpcClient;
 
 use crate::burn::burn_one;
+use crate::collections::{approve_delegate, revoke_delegate};
 use crate::decode::decode_metadata;
 use crate::derive::{get_cmv2_pda, get_edition_pda, get_generic_pda, get_metadata_pda};
 use crate::mint::{mint_list, mint_one};
@@ -11,6 +12,21 @@ use crate::snapshot::{snapshot_cm_accounts, snapshot_holders, snapshot_mints};
 use crate::update_metadata::*;
 use crate::withdraw::{withdraw, WithdrawArgs};
 
+pub fn process_collections(client: &RpcClient, commands: CollectionsSubcommands) -> Result<()> {
+    match commands {
+        CollectionsSubcommands::ApproveAuthority {
+            keypair,
+            collection_mint,
+            delegate_authority,
+        } => approve_delegate(client, keypair, collection_mint, delegate_authority),
+        CollectionsSubcommands::RevokeAuthority {
+            keypair,
+            collection_mint,
+            delegate_authority,
+        } => revoke_delegate(client, keypair, collection_mint, delegate_authority),
+    }
+}
+
 pub fn process_burn(client: &RpcClient, commands: BurnSubcommands) -> Result<()> {
     match commands {
         BurnSubcommands::One { keypair, account } => burn_one(client, keypair, account),
@@ -23,8 +39,16 @@ pub fn process_decode(client: &RpcClient, commands: DecodeSubcommands) -> Result
             account,
             full,
             list_file,
+            raw,
             ref output,
-        } => decode_metadata(client, account.as_ref(), full, list_file.as_ref(), output)?,
+        } => decode_metadata(
+            client,
+            account.as_ref(),
+            full,
+            list_file.as_ref(),
+            raw,
+            output,
+        )?,
     }
     Ok(())
 }
@@ -47,6 +71,7 @@ pub fn process_mint(client: &RpcClient, commands: MintSubcommands) -> Result<()>
             external_metadata_uri,
             immutable,
             primary_sale_happened,
+            sign,
         } => mint_one(
             &client,
             &keypair,
@@ -55,6 +80,7 @@ pub fn process_mint(client: &RpcClient, commands: MintSubcommands) -> Result<()>
             external_metadata_uri.as_ref(),
             immutable,
             primary_sale_happened,
+            sign,
         ),
         MintSubcommands::List {
             keypair,
@@ -63,6 +89,7 @@ pub fn process_mint(client: &RpcClient, commands: MintSubcommands) -> Result<()>
             external_metadata_uris,
             immutable,
             primary_sale_happened,
+            sign,
         } => mint_list(
             &client,
             keypair,
@@ -71,6 +98,7 @@ pub fn process_mint(client: &RpcClient, commands: MintSubcommands) -> Result<()>
             external_metadata_uris,
             immutable,
             primary_sale_happened,
+            sign,
         ),
     }
 }
@@ -110,10 +138,18 @@ pub fn process_sign(client: &RpcClient, commands: SignSubcommands) -> Result<()>
         SignSubcommands::One { keypair, account } => sign_one(&client, keypair, account),
         SignSubcommands::All {
             keypair,
-            candy_machine_id,
+            creator,
+            position,
             v2,
             mint_accounts_file,
-        } => sign_all(&client, &keypair, candy_machine_id, v2, mint_accounts_file),
+        } => sign_all(
+            &client,
+            &keypair,
+            &creator,
+            position,
+            v2,
+            mint_accounts_file,
+        ),
     }
 }
 
@@ -121,25 +157,52 @@ pub fn process_snapshot(client: &RpcClient, commands: SnapshotSubcommands) -> Re
     match commands {
         SnapshotSubcommands::Holders {
             update_authority,
-            candy_machine_id,
+            creator,
+            position,
+            mint_accounts_file,
             v2,
             output,
-        } => snapshot_holders(&client, &update_authority, &candy_machine_id, v2, &output),
+        } => snapshot_holders(
+            &client,
+            &update_authority,
+            &creator,
+            position,
+            &mint_accounts_file,
+            v2,
+            &output,
+        ),
         SnapshotSubcommands::CMAccounts {
             update_authority,
             output,
         } => snapshot_cm_accounts(&client, &update_authority, &output),
         SnapshotSubcommands::Mints {
-            candy_machine_id,
+            creator,
+            position,
             update_authority,
             v2,
             output,
-        } => snapshot_mints(&client, candy_machine_id, update_authority, v2, output),
+        } => snapshot_mints(&client, &creator, position, update_authority, v2, output),
     }
 }
 
 pub fn process_update(client: &RpcClient, commands: UpdateSubcommands) -> Result<()> {
     match commands {
+        UpdateSubcommands::Name {
+            keypair,
+            account,
+            new_name,
+        } => update_name_one(&client, &keypair, &account, &new_name),
+        UpdateSubcommands::Symbol {
+            keypair,
+            account,
+            new_symbol,
+        } => update_symbol_one(&client, &keypair, &account, &new_symbol),
+        UpdateSubcommands::Creators {
+            keypair,
+            account,
+            new_creators,
+            append,
+        } => update_creator_by_position(&client, &keypair, &account, &new_creators, append),
         UpdateSubcommands::Data {
             keypair,
             account,
