@@ -28,11 +28,11 @@ use std::{
     sync::{Arc, Mutex},
 };
 
-use crate::constants::*;
 use crate::derive::derive_cmv2_pda;
 use crate::limiter::create_rate_limiter;
 use crate::parse::{first_creator_is_verified, is_only_one_option};
 use crate::spinner::*;
+use crate::{constants::*, decode::get_metadata_pda};
 
 #[derive(Debug, Serialize, Clone)]
 struct Holder {
@@ -62,12 +62,13 @@ struct CandyMachineAccount {
 
 pub fn snapshot_mints(
     client: &RpcClient,
-    candy_machine_id: Option<String>,
+    creator: &Option<String>,
+    position: usize,
     update_authority: Option<String>,
     v2: bool,
     output: String,
 ) -> Result<()> {
-    if !is_only_one_option(&candy_machine_id, &update_authority) {
+    if !is_only_one_option(&creator, &update_authority) {
         return Err(anyhow!(
             "Please specify either a candy machine id or an update authority, but not both."
         ));
@@ -76,15 +77,15 @@ pub fn snapshot_mints(
     let spinner = create_spinner("Getting accounts...");
     let accounts = if let Some(ref update_authority) = update_authority {
         get_mints_by_update_authority(client, &update_authority)?
-    } else if let Some(ref candy_machine_id) = candy_machine_id {
+    } else if let Some(ref creator) = creator {
         // Support v2 cm ids
         if v2 {
-            let cm_pubkey = Pubkey::from_str(&candy_machine_id)
-                .expect("Failed to parse pubkey from candy_machine_id!");
-            let cmv2_id = derive_cmv2_pda(&cm_pubkey);
-            get_cm_creator_accounts(client, &cmv2_id.to_string())?
+            let creator_pubkey =
+                Pubkey::from_str(&creator).expect("Failed to parse pubkey from creator!");
+            let cmv2_creator = derive_cmv2_pda(&creator_pubkey);
+            get_cm_creator_accounts(client, &cmv2_creator.to_string(), position)?
         } else {
-            get_cm_creator_accounts(client, &candy_machine_id)?
+            get_cm_creator_accounts(client, &creator, position)?
         }
     } else {
         return Err(anyhow!(
@@ -97,8 +98,14 @@ pub fn snapshot_mints(
     println!("Getting metadata and writing to file...");
     let mut mint_accounts: Vec<String> = Vec::new();
 
-    for (_, account) in accounts {
-        let metadata: Metadata = try_from_slice_unchecked(&account.data)?;
+    for (pubkey, account) in accounts {
+        let metadata: Metadata = match try_from_slice_unchecked(&account.data) {
+            Ok(metadata) => metadata,
+            Err(_) => {
+                error!("Failed to parse metadata for account {}", pubkey);
+                continue;
+            }
+        };
 
         if first_creator_is_verified(&metadata.data.creators) {
             mint_accounts.push(metadata.mint.to_string());
@@ -107,8 +114,8 @@ pub fn snapshot_mints(
 
     let prefix = if let Some(update_authority) = update_authority {
         update_authority
-    } else if let Some(candy_machine_id) = candy_machine_id {
-        candy_machine_id
+    } else if let Some(creator) = creator {
+        creator.clone()
     } else {
         return Err(anyhow!(
             "Must specify either --update-authority or --candy-machine-id"
@@ -124,7 +131,9 @@ pub fn snapshot_mints(
 pub fn snapshot_holders(
     client: &RpcClient,
     update_authority: &Option<String>,
-    candy_machine_id: &Option<String>,
+    creator: &Option<String>,
+    position: usize,
+    mint_accounts_file: &Option<String>,
     v2: bool,
     output: &String,
 ) -> Result<()> {
@@ -134,19 +143,23 @@ pub fn snapshot_holders(
     let spinner = create_spinner("Getting accounts...");
     let accounts = if let Some(update_authority) = update_authority {
         get_mints_by_update_authority(client, update_authority)?
-    } else if let Some(candy_machine_id) = candy_machine_id {
+    } else if let Some(creator) = creator {
         // Support v2 cm ids
         if v2 {
-            let cm_pubkey = Pubkey::from_str(&candy_machine_id)
-                .expect("Failed to parse pubkey from candy_machine_id!");
-            let cmv2_id = derive_cmv2_pda(&cm_pubkey);
-            get_cm_creator_accounts(client, &cmv2_id.to_string())?
+            let creator_pubkey =
+                Pubkey::from_str(&creator).expect("Failed to parse pubkey from creator!");
+            let cmv2_creator = derive_cmv2_pda(&creator_pubkey);
+            get_cm_creator_accounts(client, &cmv2_creator.to_string(), position)?
         } else {
-            get_cm_creator_accounts(client, &candy_machine_id)?
+            get_cm_creator_accounts(client, &creator, position)?
         }
+    } else if let Some(mint_accounts_file) = mint_accounts_file {
+        let file = File::open(mint_accounts_file)?;
+        let mint_accounts: Vec<String> = serde_json::from_reader(&file)?;
+        get_mint_account_infos(client, mint_accounts)?
     } else {
         return Err(anyhow!(
-            "Must specify either --update-authority or --candy-machine-id"
+            "Must specify either --update-authority or --candy-machine-id or --mint-accounts-file"
         ));
     };
     spinner.finish_with_message("Getting accounts...Done!");
@@ -239,12 +252,14 @@ pub fn snapshot_holders(
         });
 
     let prefix = if let Some(update_authority) = update_authority {
-        update_authority
-    } else if let Some(candy_machine_id) = candy_machine_id {
-        candy_machine_id
+        update_authority.clone()
+    } else if let Some(creator) = creator {
+        creator.clone()
+    } else if let Some(mint_accounts_file) = mint_accounts_file {
+        str::replace(mint_accounts_file, ".json", "")
     } else {
         return Err(anyhow!(
-            "Must specify either --update-authority or --candy-machine-id"
+            "Must specify either --update-authority or --candy-machine-id or --mint-accounts-file"
         ));
     };
 
@@ -254,6 +269,50 @@ pub fn snapshot_holders(
     Ok(())
 }
 
+fn get_mint_account_infos(
+    client: &RpcClient,
+    mint_accounts: Vec<String>,
+) -> Result<Vec<(Pubkey, Account)>> {
+    let use_rate_limit = *USE_RATE_LIMIT.read().unwrap();
+    let handle = create_rate_limiter();
+
+    let address_account_pairs: Arc<Mutex<Vec<(Pubkey, Account)>>> =
+        Arc::new(Mutex::new(Vec::new()));
+
+    mint_accounts.par_iter().for_each(|mint_account| {
+        let mut handle = handle.clone();
+        if use_rate_limit {
+            handle.wait();
+        }
+
+        let mint_pubkey = match Pubkey::from_str(mint_account) {
+            Ok(pubkey) => pubkey,
+            Err(_) => {
+                error!("Invalid mint address {}", mint_account);
+                return;
+            }
+        };
+
+        let metadata_pubkey = get_metadata_pda(mint_pubkey);
+
+        let account_info = match client.get_account(&metadata_pubkey) {
+            Ok(account) => account,
+            Err(_) => {
+                error!("Error in fetching metadata for mint {}", mint_account);
+                return;
+            }
+        };
+
+        address_account_pairs
+            .lock()
+            .unwrap()
+            .push((mint_pubkey, account_info))
+    });
+
+    let res = address_account_pairs.lock().unwrap().clone();
+    Ok(res)
+}
+
 fn get_mints_by_update_authority(
     client: &RpcClient,
     update_authority: &String,
@@ -344,8 +403,14 @@ fn get_cm_accounts_by_update_authority(
 
 pub fn get_cm_creator_accounts(
     client: &RpcClient,
-    candy_machine_id: &String,
+    creator: &String,
+    position: usize,
 ) -> Result<Vec<(Pubkey, Account)>> {
+    if position > 4 {
+        error!("CM Creator position cannot be greator than 4");
+        std::process::exit(1);
+    }
+
     let config = RpcProgramAccountsConfig {
         filters: Some(vec![RpcFilterType::Memcmp(Memcmp {
             offset: 1 + // key
@@ -359,8 +424,14 @@ pub fn get_cm_creator_accounts(
             MAX_SYMBOL_LENGTH + // symbol
             2 + // seller fee basis points
             1 + // whether or not there is a creators vec
-            4, // creators
-            bytes: MemcmpEncodedBytes::Base58(candy_machine_id.to_string()),
+            4 + // creators
+            position * // index for each creator
+            (
+                32 + // address
+                1 + // verified
+                1 // share
+            ),
+            bytes: MemcmpEncodedBytes::Base58(creator.to_string()),
             encoding: None,
         })]),
         account_config: RpcAccountInfoConfig {
