@@ -1,7 +1,7 @@
 use anyhow::{anyhow, Result};
 use glob::glob;
 use indicatif::ParallelProgressIterator;
-use log::{error, info};
+use log::{error, info, warn};
 use mpl_token_metadata::{
     instruction::{update_metadata_accounts, update_metadata_accounts_v2},
     state::Data,
@@ -15,6 +15,7 @@ use solana_sdk::{
     transaction::Transaction,
 };
 use std::{
+    cmp,
     fs::File,
     path::Path,
     str::FromStr,
@@ -25,7 +26,92 @@ use crate::constants::*;
 use crate::data::{NFTData, UpdateNFTData, UpdateUriData};
 use crate::decode::{decode, get_metadata_pda};
 use crate::limiter::create_rate_limiter;
-use crate::parse::{convert_local_to_remote_data, parse_keypair};
+use crate::parse::{convert_local_to_remote_data, parse_cli_creators, parse_keypair};
+
+pub fn update_name_one(
+    client: &RpcClient,
+    keypair: &String,
+    mint_account: &String,
+    new_name: &String,
+) -> Result<()> {
+    let parsed_keypair = parse_keypair(keypair)?;
+    let data_with_old_name = decode(client, mint_account)?.data;
+    let new_data: Data = Data {
+        creators: data_with_old_name.creators,
+        seller_fee_basis_points: data_with_old_name.seller_fee_basis_points,
+        name: new_name.to_owned(),
+        symbol: data_with_old_name.symbol,
+        uri: data_with_old_name.uri,
+    };
+
+    update_data(client, &parsed_keypair, mint_account, new_data)?;
+    Ok(())
+}
+
+pub fn update_symbol_one(
+    client: &RpcClient,
+    keypair: &String,
+    mint_account: &String,
+    new_symbol: &String,
+) -> Result<()> {
+    let parsed_keypair = parse_keypair(keypair)?;
+    let data_with_old_symbol = decode(client, mint_account)?.data;
+    let new_data: Data = Data {
+        creators: data_with_old_symbol.creators,
+        seller_fee_basis_points: data_with_old_symbol.seller_fee_basis_points,
+        name: data_with_old_symbol.name,
+        symbol: new_symbol.to_owned(),
+        uri: data_with_old_symbol.uri,
+    };
+
+    update_data(client, &parsed_keypair, mint_account, new_data)?;
+    Ok(())
+}
+
+pub fn update_creator_by_position(
+    client: &RpcClient,
+    keypair: &String,
+    mint_account: &String,
+    new_creators: &String,
+    should_append: bool,
+) -> Result<()> {
+    let parsed_keypair = parse_keypair(keypair)?;
+    let data_with_old_creators = decode(client, mint_account)?.data;
+    let parsed_creators = parse_cli_creators(new_creators.to_string(), should_append)?;
+
+    let new_creators = if let Some(mut old_creators) = data_with_old_creators.creators {
+        if !should_append {
+            parsed_creators
+        } else {
+            let remaining_space = 5 - old_creators.len();
+            warn!(
+                "Appending {} new creators with old creators with shares of 0",
+                parsed_creators.len()
+            );
+            let end_index = cmp::min(parsed_creators.len(), remaining_space);
+            old_creators.append(&mut parsed_creators[0..end_index].to_vec());
+            old_creators
+        }
+    } else {
+        parsed_creators
+    };
+
+    let shares = new_creators.iter().fold(0, |acc, c| acc + c.share);
+    if shares != 100 {
+        return Err(anyhow!("Creators shares must sum to 100!"));
+    }
+
+    let new_data: Data = Data {
+        creators: Some(new_creators),
+        seller_fee_basis_points: data_with_old_creators.seller_fee_basis_points,
+        name: data_with_old_creators.name,
+        symbol: data_with_old_creators.symbol,
+        uri: data_with_old_creators.uri,
+    };
+
+    update_data(client, &parsed_keypair, mint_account, new_data)?;
+    Ok(())
+}
 
 pub fn update_data_one(
     client: &RpcClient,
